@@ -1,11 +1,7 @@
 /*
-**  Copyright (c) 2010-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2010-2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char dkim_atps_c_id[] = "@(#)$Id$";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -239,6 +235,14 @@ dkim_atps_check(DKIM *dkim, DKIM_SIGINFO *sig, struct timeval *timeout,
 
 	/* XXX -- add QUERY_CACHE support here */
 
+	if (lib->dkiml_dns_service == NULL &&
+	    lib->dkiml_dns_init != NULL &&
+	    lib->dkiml_dns_init(&lib->dkiml_dns_service) != 0)
+	{
+		*res = DKIM_ATPS_UNKNOWN;
+		return DKIM_STAT_CANTVRFY;
+	}
+
 	/* send it */
 	anslen = sizeof ansbuf;
 	status = lib->dkiml_dns_start(lib->dkiml_dns_service, T_TXT,
