@@ -2,7 +2,7 @@
 **  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -1217,7 +1217,7 @@ dkim_canon_runheaders(DKIM *dkim)
 			else
 				hdrtest = &lib->dkiml_hdrre;
 
-			memset(hdrset, '\0', sizeof hdrset);
+			memset(hdrset, '\0', sizeof *hdrset);
 			nhdrs = 0;
 
 			/* tag headers to be signed */
