@@ -2,16 +2,12 @@
 **  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2012, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_POLICY_H_
 #define _DKIM_POLICY_H_
 
-#ifndef lint
-static char dkim_policy_h_id[] = "@(#)$Id: dkim-policy.h,v 1.4.58.1 2010/10/27 21:43:08 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
