@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2010, 2012, The Trusted Domain Project.
+**  Copyright (c) 2009, 2010, 2012, 2013, The Trusted Domain Project.
 **    All rights reserved.
 */
 
@@ -36,6 +36,11 @@
 #include "dkim-util.h"
 #include "dkim-test.h"
 
+/* libbsd if found */
+#ifdef USE_BSD_H
+# include <bsd/string.h>
+#endif /* USE_BSD_H */
+
 /* libstrl if needed */
 #ifdef USE_STRL_H
 # include <strl.h>
