@@ -30,7 +30,7 @@ extern "C" {
 **  	pp == patch number
 */
 
-#define	OPENDKIM_LIB_VERSION	0x02080400
+#define	OPENDKIM_LIB_VERSION	0x02090100
 
 #ifdef __STDC__
 # ifndef __P
@@ -276,23 +276,24 @@ typedef int dkim_opts_t;
 #define	DKIM_OPTS_MINKEYBITS	14
 #define	DKIM_OPTS_REQUIREDHDRS	15
 
-#define	DKIM_LIBFLAGS_NONE		0x0000
-#define	DKIM_LIBFLAGS_TMPFILES		0x0001
-#define	DKIM_LIBFLAGS_KEEPFILES		0x0002
-#define	DKIM_LIBFLAGS_SIGNLEN		0x0004
-#define DKIM_LIBFLAGS_CACHE		0x0008
-#define DKIM_LIBFLAGS_ZTAGS		0x0010
-#define DKIM_LIBFLAGS_DELAYSIGPROC	0x0020
-#define DKIM_LIBFLAGS_EOHCHECK		0x0040
-#define DKIM_LIBFLAGS_ACCEPTV05		0x0080
-#define DKIM_LIBFLAGS_FIXCRLF		0x0100
-#define DKIM_LIBFLAGS_ACCEPTDK		0x0200
-#define DKIM_LIBFLAGS_BADSIGHANDLES	0x0400
-#define DKIM_LIBFLAGS_VERIFYONE		0x0800
-#define DKIM_LIBFLAGS_STRICTHDRS	0x1000
-#define DKIM_LIBFLAGS_REPORTBADADSP	0x2000
-#define DKIM_LIBFLAGS_DROPSIGNER	0x4000
-#define DKIM_LIBFLAGS_STRICTRESIGN	0x8000
+#define	DKIM_LIBFLAGS_NONE		0x00000000
+#define	DKIM_LIBFLAGS_TMPFILES		0x00000001
+#define	DKIM_LIBFLAGS_KEEPFILES		0x00000002
+#define	DKIM_LIBFLAGS_SIGNLEN		0x00000004
+#define DKIM_LIBFLAGS_CACHE		0x00000008
+#define DKIM_LIBFLAGS_ZTAGS		0x00000010
+#define DKIM_LIBFLAGS_DELAYSIGPROC	0x00000020
+#define DKIM_LIBFLAGS_EOHCHECK		0x00000040
+#define DKIM_LIBFLAGS_ACCEPTV05		0x00000080
+#define DKIM_LIBFLAGS_FIXCRLF		0x00000100
+#define DKIM_LIBFLAGS_ACCEPTDK		0x00000200
+#define DKIM_LIBFLAGS_BADSIGHANDLES	0x00000400
+#define DKIM_LIBFLAGS_VERIFYONE		0x00000800
+#define DKIM_LIBFLAGS_STRICTHDRS	0x00001000
+#define DKIM_LIBFLAGS_REPORTBADADSP	0x00002000
+#define DKIM_LIBFLAGS_DROPSIGNER	0x00004000
+#define DKIM_LIBFLAGS_STRICTRESIGN	0x00008000
+#define DKIM_LIBFLAGS_REQUESTREPORTS	0x00010000
 
 #define	DKIM_LIBFLAGS_DEFAULT		DKIM_LIBFLAGS_NONE
 
@@ -1505,23 +1506,6 @@ extern DKIM_STAT dkim_setpartial __P((DKIM *dkim, _Bool value));
 
 extern DKIM_STAT dkim_set_margin __P((DKIM *dkim, int value));
 
-/*
-**  DKIM_GET_REPUTATION -- query reputation service about a signature
-**                         (OBSOLETE; moved to libdkimrep)
-**
-**  Parameters:
-**  	dkim -- DKIM handle
-**  	sig -- DKIM_SIGINFO handle
-**  	qroot -- query root
-**  	rep -- integer reputation (returned)
-**
-**  Return value:
-**  	DKIM_STAT_NOTIMPLEMENT -- not implemented
-*/
-
-extern DKIM_STAT dkim_get_reputation __P((DKIM *dkim, DKIM_SIGINFO *sig,
-                                          char *qroot, int *rep));
-
 /*
 **  DKIM_MAIL_PARSE -- extract the local-part and domain-name from a structured
 **                     header field
@@ -1562,7 +1546,7 @@ extern unsigned long dkim_ssl_version __P((void));
 */
 
 #define DKIM_FEATURE_DIFFHEADERS	0
-#define DKIM_FEATURE_DKIM_REPUTATION	1
+#define DKIM_FEATURE_UNUSED		1
 #define DKIM_FEATURE_PARSE_TIME		2
 #define DKIM_FEATURE_QUERY_CACHE	3
 #define DKIM_FEATURE_SHA256		4
