@@ -2,13 +2,9 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char t_test118_c_id[] = "@(#)$Id: t-test118.c,v 1.4 2010/09/02 05:10:57 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -170,7 +166,7 @@ main(int argc, char **argv)
 	status = dkim_eom(dkim, NULL);
 	assert(status == DKIM_STAT_OK);
 
-	status = dkim_policy(dkim, &pcode, NULL);
+	status = dkim_policy(dkim, &pcode, NULL, NULL);
 	assert(status == DKIM_STAT_OK);
 
 	presult = dkim_getpresult(dkim);
