@@ -2,13 +2,9 @@
 **  Copyright (c) 2007, 2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char vbr_c_id[] = "@(#)$Id: vbr.c,v 1.5.2.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 /* for Solaris */
 #ifndef _REENTRANT
 # define _REENTRANT
@@ -98,6 +94,11 @@ struct vbr_handle
 			                  size_t,
 			                  void **);
 	int		(*vbr_dns_cancel) (void *, void *);
+	int		(*vbr_dns_init) (void **);
+	void		(*vbr_dns_close) (void *);
+	int		(*vbr_dns_setns) (void *, const char *);
+	int		(*vbr_dns_config) (void *, const char *);
+	int		(*vbr_dns_trustanchor) (void *, const char *);
 	int		(*vbr_dns_waitreply) (void *,
 			                      void *,
 			                      struct timeval *,
@@ -111,7 +112,7 @@ static void vbr_error __P((VBR *, const char *, ...));
 
 /* ========================= PRIVATE SECTION ========================= */
 
-#if HAVE_STRLCPY == 0
+#if USE_STRL_HCPY == 0
 
 /*
 **  Copyright (c) 1999-2002, Sendmail Inc. and its suppliers.
@@ -121,7 +122,7 @@ static void vbr_error __P((VBR *, const char *, ...));
 **  forth in the LICENSE file which can be found at the top level of
 **  the sendmail distribution.
 **
-**  Copyright (c) 2009, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, The Trusted Domain Project.  All rights reserved.
 */
 
 /*
@@ -180,7 +181,7 @@ vbr_strlcpy(dst, src, size)
 	else
 		return i + strlen(src + i);
 }
-#endif /* HAVE_STRLCPY == 0 */
+#endif /* USE_STRL_HCPY == 0 */
 
 /*
 **  VBR_MALLOC -- allocate memory
@@ -710,6 +711,11 @@ vbr_init(void *(*caller_mallocf)(void *closure, size_t nbytes),
 	new->vbr_dns_start = vbr_res_query;
 	new->vbr_dns_waitreply = vbr_res_waitreply;
 	new->vbr_dns_cancel = vbr_res_cancel;
+	new->vbr_dns_init = NULL;
+	new->vbr_dns_close = NULL;
+	new->vbr_dns_setns = NULL;
+	new->vbr_dns_config = NULL;
+	new->vbr_dns_trustanchor = NULL;
 
 	return new;
 }
@@ -754,6 +760,9 @@ vbr_close(VBR *vbr)
 {
 	assert(vbr != NULL);
 
+	if (vbr->vbr_dns_close != NULL && vbr->vbr_dns_service != NULL)
+		(void) vbr->vbr_dns_close(vbr->vbr_dns_service);
+
 	CLOBBER(vbr->vbr_error);
 
 	CLOBBER(vbr);
@@ -1052,6 +1061,16 @@ vbr_query(VBR *vbr, u_char **res, u_char **cert)
 
 		qh = NULL;
 
+		if (vbr->vbr_dns_init != NULL &&
+		    vbr->vbr_dns_service == NULL &&
+		    vbr->vbr_dns_init(&vbr->vbr_dns_service) != 0)
+		{
+			snprintf(vbr->vbr_error, sizeof vbr->vbr_error,
+			         "unable to start resolver for '%s'",
+			         query);
+			return VBR_STAT_DNSERROR;
+		}
+
 		status = vbr->vbr_dns_start(vbr->vbr_dns_service, T_TXT, query,
 		                            vq->vq_buf, sizeof vq->vq_buf,
 		                            &vq->vq_qh);
@@ -1309,3 +1328,248 @@ vbr_dns_set_query_waitreply(VBR *vbr, int (*func)(void *, void *,
 
 	vbr->vbr_dns_waitreply = func;
 }
+
+/*
+**  VBR_DNS_SET_INIT -- stores a pointer to a function that initializes
+**                      a resolver
+**
+**  Parameters:
+**  	vbr -- VBR library handle
+**  	func -- function to use to initialize a resolver
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int (status)
+**  		void **dns -- DNS service handle (returned)
+*/
+
+void
+vbr_dns_set_init(VBR *vbr, int (*func)(void **))
+{
+	assert(vbr != NULL);
+
+	vbr->vbr_dns_init = func;
+}
+
+/*
+**  VBR_DNS_SET_CLOSE -- stores a pointer to a function that terminates
+**                       a resolver
+**
+**  Parameters:
+**  	vbr -- VBR library handle
+**  	func -- function to use to terminate a resolver
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns void
+**  		void *dns -- DNS service handle
+*/
+
+void
+vbr_dns_set_close(VBR *vbr, void (*func)(void *))
+{
+	assert(vbr != NULL);
+
+	vbr->vbr_dns_close = func;
+}
+
+/*
+**  VBR_DNS_SET_NSLIST -- stores a pointer to a function that updates
+**                        the active nameserver list
+**
+**  Parameters:
+**  	vbr -- VBR library handle
+**  	func -- function to use to update the active nameserver list
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int (status)
+**  		void *dns -- DNS service handle
+**  		const char *nslist -- nameserver list
+*/
+
+void
+vbr_dns_set_nslist(VBR *vbr, int (*func)(void *, const char *))
+{
+	assert(vbr != NULL);
+
+	vbr->vbr_dns_setns = func;
+}
+
+/*
+**  VBR_DNS_SET_CONFIG -- stores a pointer to a function that provides
+**                        resolver configuration
+**
+**  Parameters:
+**  	vbr -- VBR library handle
+**  	func -- function to use to pass resolver configuration data
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int (status)
+**  		void *dns -- DNS service handle
+**  		const char *config -- resolver configuration data
+*/
+
+void
+vbr_dns_set_config(VBR *vbr, int (*func)(void *, const char *))
+{
+	assert(vbr != NULL);
+
+	vbr->vbr_dns_config = func;
+}
+
+/*
+**  VBR_DNS_SET_TRUSTANCHOR -- stores a pointer to a function that provides
+**                             trust anchor data
+**
+**  Parameters:
+**  	vbr -- VBR library handle
+**  	func -- function to use to pass trust anchor data
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int (status)
+**  		void *dns -- DNS service handle
+**  		const char *trust -- trust anchor data
+*/
+
+void
+vbr_dns_set_trustanchor(VBR *vbr, int (*func)(void *, const char *))
+{
+	assert(vbr != NULL);
+
+	vbr->vbr_dns_trustanchor = func;
+}
+
+/*
+**  VBR_DNS_NSLIST -- requests update to a nameserver list
+**
+**  Parameters:
+**  	lib -- RBL library handle
+**  	nslist -- comma-separated list of nameservers to use
+**
+**  Return value:
+**  	An VBR_STAT_* constant.
+*/
+
+VBR_STAT
+vbr_dns_nslist(VBR *lib, const char *nslist)
+{
+	int status;
+
+	assert(lib != NULL);
+	assert(nslist != NULL);
+
+	if (lib->vbr_dns_setns != NULL)
+	{
+		status = lib->vbr_dns_setns(lib->vbr_dns_service, nslist);
+		if (status != 0)
+			return VBR_STAT_DNSERROR;
+	}
+
+	return VBR_STAT_OK;
+}
+
+/*
+**  VBR_DNS_CONFIG -- requests a change to resolver configuration
+**
+**  Parameters:
+**  	lib -- RBL library handle
+**  	config -- opaque configuration string
+**
+**  Return value:
+**  	An VBR_STAT_* constant.
+*/
+
+VBR_STAT
+vbr_dns_config(VBR *lib, const char *config)
+{
+	int status;
+
+	assert(lib != NULL);
+	assert(config != NULL);
+
+	if (lib->vbr_dns_config != NULL)
+	{
+		status = lib->vbr_dns_config(lib->vbr_dns_service, config);
+		if (status != 0)
+			return VBR_STAT_DNSERROR;
+	}
+
+	return VBR_STAT_OK;
+}
+
+/*
+**  VBR_DNS_TRUSTANCHOR -- requests a change to resolver trust anchor data
+**
+**  Parameters:
+**  	lib -- RBL library handle
+**  	trust -- opaque trust anchor string
+**
+**  Return value:
+**  	An VBR_STAT_* constant.
+*/
+
+VBR_STAT
+vbr_dns_trustanchor(VBR *lib, const char *trust)
+{
+	int status;
+
+	assert(lib != NULL);
+	assert(trust != NULL);
+
+	if (lib->vbr_dns_trustanchor != NULL)
+	{
+		status = lib->vbr_dns_trustanchor(lib->vbr_dns_service, trust);
+		if (status != 0)
+			return VBR_STAT_DNSERROR;
+	}
+
+	return VBR_STAT_OK;
+}
+
+/*
+**  VBR_DNS_INIT -- force nameserver (re)initialization
+**
+**  Parameters:
+**  	lib -- RBL library handle
+**
+**  Return value:
+**  	An VBR_STAT_* constant.
+*/
+
+VBR_STAT
+vbr_dns_init(VBR *lib)
+{
+	int status;
+
+	assert(lib != NULL);
+
+	if (lib->vbr_dns_service != NULL &&
+	    lib->vbr_dns_close != NULL)
+		lib->vbr_dns_close(lib->vbr_dns_service);
+
+	lib->vbr_dns_service = NULL;
+
+	if (lib->vbr_dns_init != NULL)
+		return lib->vbr_dns_init(&lib->vbr_dns_service);
+	else
+		return VBR_STAT_OK;
+}
+
