@@ -2,18 +2,14 @@
 **  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009, 2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2012, 2013, The Trusted Domain Project.
+**  	All rights reserved.
 **
-**  $Id: opendkim-ar.h,v 1.1 2009/07/16 20:59:11 cm-msk Exp $
 */
 
 #ifndef _OPENDKIM_AR_H_
 #define _OPENDKIM_AR_H_
 
-#ifndef lint
-static char opendkim_ar_h_id[] = "@(#)$Id: opendkim-ar.h,v 1.1 2009/07/16 20:59:11 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/types.h>
 
@@ -37,6 +33,7 @@ typedef int ares_method_t;
 #define	ARES_METHOD_DKIMADSP	5
 #define	ARES_METHOD_IPREV	6
 #define	ARES_METHOD_DKIMATPS	7
+#define	ARES_METHOD_DMARC	8
 
 /* ARES_RESULT_T -- type for specifying an authentication result */
 typedef int ares_result_t;
