@@ -2,8 +2,7 @@
 **  Copyright (c) 2006-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
-**
+**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_CONFIG_H_
@@ -57,12 +56,6 @@ struct configdef dkimf_config[] =
 	{ "DiagnosticDirectory",	CONFIG_TYPE_STRING,	FALSE },
 	{ "DisableADSP",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "DisableCryptoInit",		CONFIG_TYPE_BOOLEAN,	FALSE },
-#ifdef _FFR_DKIM_REPUTATION
-	{ "DKIMReputationFail",		CONFIG_TYPE_INTEGER,	FALSE },
-	{ "DKIMReputationPass",		CONFIG_TYPE_INTEGER,	FALSE },
-	{ "DKIMReputationReject",	CONFIG_TYPE_INTEGER,	FALSE },
-	{ "DKIMReputationRoot",		CONFIG_TYPE_STRING,	FALSE },
-#endif /* _FFR_DKIM_REPUTATION */
 	{ "DNSConnect",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "DNSTimeout",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "Domain",			CONFIG_TYPE_STRING,	FALSE },
@@ -110,6 +103,9 @@ struct configdef dkimf_config[] =
 	{ "LocalADSP",			CONFIG_TYPE_STRING,	FALSE },
 	{ "LogResults",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "LogWhy",			CONFIG_TYPE_BOOLEAN,	FALSE },
+#ifdef _FFR_LUA_ONLY_SIGNING
+	{ "LuaOnlySigning",		CONFIG_TYPE_BOOLEAN,	FALSE },
+#endif /* _FFR_LUA_ONLY_SIGNING */
 	{ "MaximumHeaders",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "MaximumSignedBytes",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "MaximumSignaturesToVerify",	CONFIG_TYPE_INTEGER,	FALSE },
@@ -153,9 +149,7 @@ struct configdef dkimf_config[] =
 #ifdef _FFR_RATE_LIMIT
 	{ "RateLimits",			CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_RATE_LIMIT */
-#ifdef _FFR_REDIRECT
 	{ "RedirectFailuresTo",		CONFIG_TYPE_STRING,	FALSE },
-#endif /* _FFR_REDIRECT */
 	{ "RemoveARAll",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "RemoveARFrom",		CONFIG_TYPE_STRING,	FALSE },
 	{ "RemoveOldSignatures",	CONFIG_TYPE_BOOLEAN,	FALSE },
