@@ -2,15 +2,11 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009, 2010 The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2010, 2012, The Trusted Domain Project.
+**    All rights reserved.
 **
-**  $Id: opendkim-testadsp.c,v 1.8 2010/06/19 15:29:12 cm-msk Exp $
 */
 
-#ifndef lint
-static char opendkim_testadsp_c_id[] = "@(#)$Id: opendkim-testadsp.c,v 1.8 2010/06/19 15:29:12 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/types.h>
 #include <sys/stat.h>
