@@ -1,4 +1,4 @@
--- Copyright (c) 2009, 2010, 2012, The Trusted Domain Project.
+-- Copyright (c) 2009, 2010, 2012, 2013, The Trusted Domain Project.
 --   All rights reserved.
 
 -- Configuration validity check
@@ -8,7 +8,11 @@
 mt.echo("*** invalid signing configuration test")
 
 -- setup
-sock = "unix:" .. mt.getcwd() .. "/t-conf-check.sock"
+if TESTSOCKET ~= nil then
+	sock = TESTSOCKET
+else
+	sock = "unix:" .. mt.getcwd() .. "/t-conf-check.sock"
+end
 binpath = mt.getcwd() .. "/.."
 if os.getenv("srcdir") ~= nil then
 	mt.chdir(os.getenv("srcdir"))
@@ -18,7 +22,7 @@ end
 mt.startfilter(binpath .. "/opendkim", "-x", "t-conf-check.conf", "-p", sock)
 
 -- try to connect to it
-conn = mt.connect(sock, 40, 0.05)
+conn = mt.connect(sock, 40, 0.25)
 if conn ~= nil then
 	error("mt.connect() succeeded (shouldn't have)")
 end
