@@ -1,13 +1,15 @@
+-- Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
 
--- Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
-
--- 
 -- verify config option LocalADSP works
 
 mt.echo("*** test config option LocalADSP")
 
 -- setup
-sock = "unix:" .. mt.getcwd() .. "/t-local-adsp.sock"
+if TESTSOCKET ~= nil then
+	sock = TESTSOCKET
+else
+	sock = "unix:" .. mt.getcwd() .. "/t-local-adsp.sock"
+end
 binpath = mt.getcwd() .. "/.."
 if os.getenv("srcdir") ~= nil then
 	mt.chdir(os.getenv("srcdir"))
@@ -18,7 +20,7 @@ mt.startfilter(binpath .. "/opendkim", "-x", "t-local-adsp.conf",
                "-p", sock)
 
 -- try to connect to it
-conn = mt.connect(sock, 40, 0.05)
+conn = mt.connect(sock, 40, 0.25)
 if conn == nil then
 	error "mt.connect() failed"
 end
