@@ -1,5 +1,4 @@
-
--- Copyright (c) 2009, 2010, 2012, The Trusted Domain Project.
+-- Copyright (c) 2009, 2010, 2012, 2013, The Trusted Domain Project.
 --   All rights reserved.
 
 -- simple/simple signing test using macros to validate origin
@@ -10,7 +9,11 @@
 mt.echo("*** simple/simple signing test using macros to validate origin (value)")
 
 -- setup
-sock = "unix:" .. mt.getcwd() .. "/t-sign-ss-macro-value.sock"
+if TESTSOCKET ~= nil then
+	sock = TESTSOCKET
+else
+	sock = "unix:" .. mt.getcwd() .. "/t-sign-ss-macro-value.sock"
+end
 binpath = mt.getcwd() .. "/.."
 if os.getenv("srcdir") ~= nil then
 	mt.chdir(os.getenv("srcdir"))
@@ -21,7 +24,7 @@ mt.startfilter(binpath .. "/opendkim", "-x", "t-sign-ss-macro-value.conf",
                "-p", sock)
 
 -- try to connect to it
-conn = mt.connect(sock, 40, 0.05)
+conn = mt.connect(sock, 40, 0.25)
 if conn == nil then
 	error("mt.connect() failed")
 end
