@@ -1,11 +1,7 @@
 /*
-**  Copyright (c) 2011, 2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2011-2013, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char repute_c_id[] = "$Id$";
-#endif /* ! lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -19,12 +15,6 @@ static char repute_c_id[] = "$Id$";
 #include <stdio.h>
 #include <string.h>
 
-#ifdef USE_XML2
-/* libxml2 includes */
-# include <libxml/parser.h>
-# include <libxml/tree.h>
-#endif /* USE_XML2 */
-
 #ifdef USE_JANSSON
 /* libjansson includes */
 # include <jansson.h>
@@ -42,6 +32,7 @@ static char repute_c_id[] = "$Id$";
 /* limits */
 #define	REPUTE_BUFBASE	1024
 #define	REPUTE_URL	1024
+#define	REPUTE_TIMEOUT	10
 
 /* data types */
 struct repute_io
@@ -67,51 +58,8 @@ struct repute_handle
 	char			rep_error[REPUTE_BUFBASE + 1];
 };
 
-struct repute_lookup
-{
-	int			rt_code;
-	const char *		rt_name;
-};
-
-/* lookup tables */
-struct repute_lookup repute_lookup_elements[] =
-{
-	{ REPUTE_XML_CODE_ASSERTION,	REPUTE_XML_ASSERTION },
-	{ REPUTE_XML_CODE_EXTENSION,	REPUTE_XML_EXTENSION },
-	{ REPUTE_XML_CODE_RATED,	REPUTE_XML_RATED },
-	{ REPUTE_XML_CODE_RATER,	REPUTE_XML_RATER },
-	{ REPUTE_XML_CODE_RATER_AUTH,	REPUTE_XML_RATER_AUTH },
-	{ REPUTE_XML_CODE_RATING,	REPUTE_XML_RATING },
-	{ REPUTE_XML_CODE_SAMPLE_SIZE,	REPUTE_XML_SAMPLE_SIZE },
-	{ REPUTE_XML_CODE_UPDATED,	REPUTE_XML_UPDATED },
-	{ REPUTE_XML_CODE_UNKNOWN,	NULL }
-};
-
-#ifdef USE_XML2
-/*
-**  REPUTE_LIBXML2_ERRHANDLER -- error handler function provided to libxml2
-**
-**  Parameters:
-**  	ctx -- a "parsing" context (generally a FILE *)
-**  	fmt -- message format
-**  	... -- variable arguments
-**
-**  Return value:
-** 	None.
-**
-**  Notes:
-**  	Oddly, libxml2 writes errors to stderr by default without a provided
-**  	handler function.  We check for errors in other ways and this
-**  	program typically runs as a daemon, so we'll suppress that by
-**  	providing an error handler that does nothing.
-*/
-
-static void
-repute_libxml2_errhandler(void *ctx, const char *fmt, ...)
-{
-	return;
-}
-#endif /* USE_XML2 */
+/* globals */
+static long timeout = REPUTE_TIMEOUT;
 
 /*
 **  REPUTE_CURL_WRITEDATA -- callback for libcurl to deliver data
@@ -172,35 +120,6 @@ repute_curl_writedata(char *ptr, size_t size, size_t nmemb, void *userdata)
 	return need;
 }
 
-/*
-**  REPUTE_NAME_TO_CODE -- look up a name in a table
-**
-**  Parameters:
-**  	tbl -- table to search
-**  	name -- name to find
-**
-**  Return value:
-**  	Matching code.
-*/
-
-static int
-repute_name_to_code(struct repute_lookup *tbl, const char *name)
-{
-	int c;
-
-	assert(tbl != NULL);
-	assert(name != NULL);
-
-	for (c = 0; ; c++)
-	{
-		if (tbl[c].rt_name == NULL ||
-		    strcasecmp(name, tbl[c].rt_name) == 0)
-			return tbl[c].rt_code;
-	}
-
-	return -1;
-}
-
 /*
 **  REPUTE_PARSE -- parse a REPUTE message
 **
@@ -222,6 +141,7 @@ repute_parse(const char *buf, size_t buflen, float *rep, float *conf,
 {
 	_Bool found_dkim = FALSE;
 	_Bool found_spam = FALSE;
+	_Bool found_appl = FALSE;
 	int code;
 	float conftmp;
 	float reptmp;
@@ -230,25 +150,16 @@ repute_parse(const char *buf, size_t buflen, float *rep, float *conf,
 	time_t whentmp;
 	char *p;
 	const char *start;
-#ifdef USE_XML2
-	xmlDocPtr doc = NULL;
-	xmlNode *node = NULL;
-	xmlNode *reputon = NULL;
-#endif /* USE_XML2 */
 #ifdef USE_JANSSON
 	json_t *root = NULL;
-	json_t *exts = NULL;
 	json_t *obj = NULL;
+	json_t *reps = NULL;
 	json_error_t error;
 #endif /* USE_JANSSON */
 
 	assert(buf != NULL);
 	assert(rep != NULL);
 
-#ifdef USE_XML2
-	xmlSetGenericErrorFunc(NULL, repute_libxml2_errhandler);
-#endif /* USE_XML2 */
-
 	/* skip any header found */
 	/* XXX -- this should verify a desirable Content-Type */
 	for (start = buf; *start != '\0'; start++)
@@ -275,44 +186,54 @@ repute_parse(const char *buf, size_t buflen, float *rep, float *conf,
 	if (root == NULL)
 		return REPUTE_STAT_PARSE;
 
-	exts = json_object_get(root, REPUTE_XML_EXTENSION);
-	if (exts != NULL && !json_is_object(exts))
-	{
-		json_decref(root);
-		return REPUTE_STAT_PARSE;
+	obj = json_object_get(root, REPUTE_APPLICATION);
+	if (obj != NULL && json_is_string(obj) &&
+	    strcasecmp(json_string_value(obj), REPUTE_APPLICATION_VAL) == 0)
+		found_appl = TRUE;
+
+	reps = json_object_get(root, REPUTE_REPUTONS);
+	if (reps != NULL && json_is_array(reps)) {
+		int n;
+		json_t *rep;
+
+		for (n = 0; n < json_array_size(reps); n++) {
+			rep = json_array_get(reps, n);
+
+			obj = json_object_get(rep, REPUTE_ASSERTION);
+			if (obj != NULL && json_is_string(obj) &&
+			    strcasecmp(json_string_value(obj),
+			               REPUTE_ASSERT_SPAM) == 0)
+				found_spam = TRUE;
+
+			obj = json_object_get(rep, REPUTE_EXT_IDENTITY);
+			if (obj != NULL && json_is_string(obj) &&
+			    strcasecmp(json_string_value(obj),
+			               REPUTE_ID_DKIM) == 0)
+				found_dkim = TRUE;
+
+			obj = json_object_get(rep, REPUTE_EXT_RATE);
+			if (obj != NULL && json_is_number(obj))
+				limittmp = (unsigned long) json_integer_value(obj);
+
+			obj = json_object_get(rep, REPUTE_CONFIDENCE);
+			if (obj != NULL && json_is_number(obj))
+				conftmp = (float) json_real_value(obj);
+
+			obj = json_object_get(rep, REPUTE_RATING);
+			if (obj != NULL && json_is_number(obj))
+				reptmp = (float) json_real_value(obj);
+
+			obj = json_object_get(rep, REPUTE_SAMPLE_SIZE);
+			if (obj != NULL && json_is_number(obj))
+				sampletmp = (unsigned long) json_integer_value(obj);
+
+			obj = json_object_get(rep, REPUTE_GENERATED);
+			if (obj != NULL && json_is_number(obj))
+				whentmp = (time_t) json_integer_value(obj);
+		}
 	}
 
-	obj = json_object_get(root, REPUTE_XML_ASSERTION);
-	if (obj != NULL && json_is_string(obj) &&
-	    strcasecmp(json_string_value(obj), REPUTE_ASSERT_SPAM) == 0)
-		found_spam = TRUE;
-
-	obj = json_object_get(exts, REPUTE_EXT_ID);
-	if (obj != NULL && json_is_string(obj) &&
-	    strcasecmp(json_string_value(obj), REPUTE_EXT_ID_DKIM) == 0)
-		found_dkim = TRUE;
-
-	obj = json_object_get(exts, REPUTE_EXT_RATE);
-	if (obj != NULL && json_is_number(obj))
-		limittmp = (unsigned long) json_integer_value(obj);
-
-	obj = json_object_get(root, REPUTE_XML_RATER_AUTH);
-	if (obj != NULL && json_is_number(obj))
-		conftmp = (float) json_real_value(obj);
-
-	obj = json_object_get(root, REPUTE_XML_RATING);
-	if (obj != NULL && json_is_number(obj))
-		reptmp = (float) json_real_value(obj);
-
-	obj = json_object_get(root, REPUTE_XML_SAMPLE_SIZE);
-	if (obj != NULL && json_is_number(obj))
-		sampletmp = (unsigned long) json_integer_value(obj);
-
-	obj = json_object_get(root, REPUTE_XML_UPDATED);
-	if (obj != NULL && json_is_number(obj))
-		whentmp = (time_t) json_integer_value(obj);
-
-	if (found_dkim && found_spam)
+	if (found_appl && found_dkim && found_spam)
 	{
 		*rep = reptmp;
 		if (conf != NULL)
@@ -324,159 +245,10 @@ repute_parse(const char *buf, size_t buflen, float *rep, float *conf,
 		if (limit != NULL)
 			*limit = limittmp;
 	}
+
+	json_decref(root);
 #endif /* USE_JANSSON */
 
-#ifdef USE_XML2
-	doc = xmlParseMemory(buf, buflen);
-	if (doc == NULL)
-		return REPUTE_STAT_PARSE;
-
-	node = xmlDocGetRootElement(doc);
-	if (node == NULL)
-	{
-		xmlFreeDoc(doc);
-		return REPUTE_STAT_PARSE;
-	}
-
-	/* confirm root's name */
-	if (node->name == NULL ||
-	    strcasecmp(node->name, REPUTE_NAME_REPUTATION) != 0 ||
-	    node->children == NULL)
-	{
-		xmlFreeDoc(doc);
-		return REPUTE_STAT_PARSE;
-	}
-
-	/* iterate through nodes looking for a reputon */
-	for (node = node->children; node != NULL; node = node->next)
-	{
-		/* skip unnamed things or things that aren't reputons */
-		if (node->name == NULL ||
-		    node->type != XML_ELEMENT_NODE ||
-		    strcasecmp(node->name, REPUTE_NAME_REPUTON) != 0 ||
-		    node->children == NULL)
-			continue;
-
-		found_dkim = FALSE;
-		found_spam = FALSE;
-		conftmp = 0.;
-		reptmp = 0.;
-		sampletmp = 0L;
-		limittmp = ULONG_MAX;
-		whentmp = 0;
-
-		for (reputon = node->children;
-		     reputon != NULL;
-		     reputon = reputon->next)
-		{
-			/* look for the reputon */
-			if (reputon->name == NULL ||
-			    reputon->type != XML_ELEMENT_NODE ||
-			    reputon->children == NULL ||
-			    reputon->children->content == NULL)
-				continue;
-
-			/* skip unknown names */
-			code = repute_name_to_code(repute_lookup_elements,
-			                           reputon->name);
-			if (code == -1)
-				continue;
-
-			switch (code)
-			{
-			  case REPUTE_XML_CODE_RATER:
-				/*
-				**  We assume for now that we got an answer
-				**  from the same place we asked.
-				*/
-
-				break;
-
-			  case REPUTE_XML_CODE_RATER_AUTH:
-				conftmp = strtof(reputon->children->content,
-				                 &p);
-				if (*p != '\0' || conftmp < 0 || conftmp > 1)
-					continue;
-
-			  case REPUTE_XML_CODE_ASSERTION:
-				if (strcasecmp(reputon->children->content,
-				               REPUTE_ASSERT_SPAM) == 0)
-					found_spam = TRUE;
-				break;
-
-			  case REPUTE_XML_CODE_EXTENSION:
-				if (strcasecmp(reputon->children->content,
-				               REPUTE_EXT_ID_BOTH) == 0)
-				{
-					found_dkim = TRUE;
-				}
-				else if (strncasecmp(reputon->children->content,
-				                     REPUTE_EXT_RATE_COLON,
-				                     sizeof REPUTE_EXT_RATE_COLON - 1) == 0)
-				{
-					errno = 0;
-					limittmp = strtoul(reputon->children->content + sizeof REPUTE_EXT_RATE_COLON,
-				                           &p, 10);
-					if (errno != 0)
-						continue;
-				}
-				break;
-
-			  case REPUTE_XML_CODE_RATED:
-				/*
-				**  We assume for now that we got an answer
-				**  to the right question.
-				*/
-
-				break;
-
-			  case REPUTE_XML_CODE_RATING:
-				reptmp = strtof(reputon->children->content,
-				                &p);
-				if (*p != '\0' || reptmp < -1 || reptmp > 1)
-					continue;
-				break;
-
-			  case REPUTE_XML_CODE_SAMPLE_SIZE:
-				errno = 0;
-				sampletmp = strtoul(reputon->children->content,
-				                    &p, 10);
-				if (errno != 0)
-					continue;
-				break;
-
-			  case REPUTE_XML_CODE_UPDATED:
-				errno = 0;
-				whentmp = strtoul(reputon->children->content,
-				                  &p, 10);
-				if (errno != 0)
-					continue;
-				break;
-
-			  default:
-				break;
-			}
-		}
-
-		if (found_dkim && found_spam)
-		{
-			*rep = reptmp;
-			if (conf != NULL)
-				*conf = conftmp;
-			if (sample != NULL)
-				*sample = sampletmp;
-			if (when != NULL)
-				*when = whentmp;
-			if (limit != NULL)
-				*limit = limittmp;
-
-			break;
-		}
-	}
-
-	xmlFreeDoc(doc);
-#endif /* USE_XML2 */
-
 	return REPUTE_STAT_OK;
 }
 
@@ -527,6 +299,7 @@ repute_get_io(REPUTE rep)
 			else
 			{
 				int status;
+				long longtmp;
 
 				status = curl_easy_setopt(rio->repute_curl,
 				                          CURLOPT_WRITEFUNCTION,
@@ -543,6 +316,15 @@ repute_get_io(REPUTE rep)
 					                        CURLOPT_USERAGENT,
 					                        rep->rep_useragent);
 				}
+
+				longtmp = 1;
+				(void) curl_easy_setopt(rio->repute_curl,
+				                        CURLOPT_NOSIGNAL,
+				                        longtmp);
+
+				(void) curl_easy_setopt(rio->repute_curl,
+				                        CURLOPT_TIMEOUT,
+				                        timeout);
 			}
 		}
 	}
@@ -649,7 +431,14 @@ repute_get_error(struct repute_io *rio, char *buf, size_t buflen)
 	if (rio->repute_rcode != 0)
 		snprintf(buf, buflen, "HTTP error code %u", rio->repute_rcode);
 	else
+#ifdef HAVE_CURL_EASY_STRERROR
 		snprintf(buf, buflen, curl_easy_strerror(rio->repute_errcode));
+#else /* HAVE_CURL_EASY_STRERROR */
+	{
+		snprintf(buf, buflen, "CURL error code %u",
+		         rio->repute_errcode);
+	}
+#endif /* HAVE_CURL_EASY_STRERROR */
 }
 
 /*
@@ -667,7 +456,6 @@ repute_get_error(struct repute_io *rio, char *buf, size_t buflen)
 static int
 repute_get_template(REPUTE rep)
 {
-	int out;
 	int cstatus;
 	long rcode;
 	struct repute_io *rio;
@@ -706,8 +494,13 @@ repute_get_template(REPUTE rep)
 	cstatus = curl_easy_setopt(rio->repute_curl, CURLOPT_WRITEDATA, rio);
 	if (cstatus != CURLE_OK)
 	{
+#ifdef HAVE_CURL_EASY_STRERROR
 		snprintf(rep->rep_error, sizeof rep->rep_error, "%s",
 		         curl_easy_strerror(cstatus));
+#else /* HAVE_CURL_EASY_STRERROR */
+		snprintf(rep->rep_error, sizeof rep->rep_error,
+		         "CURL error code %d", cstatus);
+#endif /* HAVE_CURL_EASY_STRERROR */
 		repute_put_io(rep, rio);
 		return REPUTE_STAT_INTERNAL;
 	}
@@ -715,8 +508,13 @@ repute_get_template(REPUTE rep)
 	cstatus = curl_easy_setopt(rio->repute_curl, CURLOPT_URL, url);
 	if (cstatus != CURLE_OK)
 	{
+#ifdef HAVE_CURL_EASY_STRERROR
 		snprintf(rep->rep_error, sizeof rep->rep_error, "%s",
 		         curl_easy_strerror(cstatus));
+#else /* HAVE_CURL_EASY_STRERROR */
+		snprintf(rep->rep_error, sizeof rep->rep_error,
+		         "CURL error code %d", cstatus);
+#endif /* HAVE_CURL_EASY_STRERROR */
 		repute_put_io(rep, rio);
 		return REPUTE_STAT_INTERNAL;
 	}
@@ -724,8 +522,13 @@ repute_get_template(REPUTE rep)
 	cstatus = curl_easy_perform(rio->repute_curl);
 	if (cstatus != CURLE_OK)
 	{
+#ifdef HAVE_CURL_EASY_STRERROR
 		snprintf(rep->rep_error, sizeof rep->rep_error, "%s",
 		         curl_easy_strerror(cstatus));
+#else /* HAVE_CURL_EASY_STRERROR */
+		snprintf(rep->rep_error, sizeof rep->rep_error,
+		         "CURL error code %d", cstatus);
+#endif /* HAVE_CURL_EASY_STRERROR */
 		repute_put_io(rep, rio);
 		return REPUTE_STAT_QUERY;
 	}
@@ -763,10 +566,6 @@ repute_get_template(REPUTE rep)
 void
 repute_init(void)
 {
-#ifdef USE_XML2
-	xmlInitParser();
-#endif /* USE_XML2 */
-
 	curl_global_init(CURL_GLOBAL_ALL);
 }
 
@@ -919,7 +718,6 @@ repute_query(REPUTE rep, const char *domain, float *repout,
 	struct repute_io *rio;
 	URITEMP ut;
 	char genurl[REPUTE_URL];
-	char template[REPUTE_URL];
 
 	assert(rep != NULL);
 	assert(domain != NULL);
@@ -951,9 +749,6 @@ repute_query(REPUTE rep, const char *domain, float *repout,
 #ifdef USE_JANSSON
 	    ut_keyvalue(ut, UT_KEYTYPE_STRING, "format", "json") != 0 ||
 #endif /* USE_JANSSON */
-#ifdef USE_XML2
-	    ut_keyvalue(ut, UT_KEYTYPE_STRING, "format", "xml") != 0 ||
-#endif /* USE_XML2 */
 	    ut_keyvalue(ut, UT_KEYTYPE_STRING,
 	                "scheme", REPUTE_URI_SCHEME) != 0 ||
 	    ut_keyvalue(ut, UT_KEYTYPE_STRING,
@@ -1029,3 +824,19 @@ repute_error(REPUTE rep)
 
 	return rep->rep_error;
 }
+
+/*
+**  REPUTE_SET_TIMEOUT -- set REPUTE query timeout
+**
+**  Parameters:
+**  	t -- timeout, in seconds
+**
+**  Return value:
+**  	None.
+*/
+
+void
+repute_set_timeout(long t)
+{
+	timeout = t;
+}
